@@ -1,20 +1,19 @@
 """
 pylibftdi - python wrapper for libftdi
 
-Copyright (c) 2010-2013 Ben Bass <benbass@codedstructure.net>
+Copyright (c) 2010-2014 Ben Bass <benbass@codedstructure.net>
 See LICENSE file for details and (absence of) warranty
 
 pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
 
+libftdi can be found at: http://www.intra2net.com/en/developer/libftdi/
 
-libftdi can be found at:
- http://www.intra2net.com/en/developer/libftdi/
 Neither libftdi nor Intra2net are associated with this project;
 if something goes wrong here, it's almost definitely my fault
 rather than a problem with the libftdi library.
 """
 
-__VERSION__ = "0.13"
+__VERSION__ = "0.14"
 __AUTHOR__ = "Ben Bass"
 
 
@@ -22,14 +21,15 @@ __ALL__ = ['Driver', 'Device', 'BitBangDevice', 'Bus', 'FtdiError',
            'ALL_OUTPUTS', 'ALL_INPUTS', 'BB_OUTPUT', 'BB_INPUT',
            'USB_VID_LIST', 'USB_PID_LIST']
 
-from pylibftdi import _base, driver, util, bitbang
+from pylibftdi import _base, driver, device, util, bitbang, serial_device
 
 # Bring them in to package scope so we can treat pylibftdi
 # as a module if we want.
 FtdiError = _base.FtdiError
 Bus = util.Bus
 Driver = driver.Driver
-Device = driver.Device
+Device = device.Device
+SerialDevice = serial_device.SerialDevice
 BitBangDevice = bitbang.BitBangDevice
 USB_VID_LIST = driver.USB_VID_LIST
 USB_PID_LIST = driver.USB_PID_LIST
