@@ -1,14 +1,15 @@
 """
 pylibftdi - python wrapper for libftdi
 
-Copyright (c) 2010-2013 Ben Bass <benbass@codedstructure.net>
+Copyright (c) 2010-2014 Ben Bass <benbass@codedstructure.net>
 See LICENSE file for details and (absence of) warranty
 
 pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
 
 """
+from pylibftdi.device import Device
 
-from pylibftdi.driver import Device, FtdiError, BITMODE_BITBANG
+from pylibftdi.driver import FtdiError, BITMODE_BITBANG
 from ctypes import c_ubyte, byref
 
 ALL_OUTPUTS = 0xFF
